"""..."""
from dataclasses import dataclass, field
from typing import List

from aligo.types.Enum import TemplateType
from aligo.types import DatClass


@dataclass
class TemplateResponse(DatClass):
    """..."""
