"""..."""
from dataclasses import dataclass, field
from typing import List

from aligo.types import DatClass
from aligo.types.Enum import TemplateType


@dataclass
class TemplateRequest(DatClass):
    """..."""
